"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const node_assert_1 = require("node:assert");
const utility_1 = require("@jfrog-pipelines/utility");
const microservice_1 = require("@jfrog-pipelines/microservice");
const MockClass_1 = require("./MockClass");
jest.mock('../driving/command/CreateStaticNodeCommand', () => ({ CreateStaticNodeCommand: MockClass_1.MockClass }));
jest.mock('../feature/node/CreateStaticNodeHandler', () => ({ CreateStaticNodeHandler: MockClass_1.MockClass }));
const CommandFactory_1 = require("../CommandFactory");
const NodeStatsCleanupHandler_1 = require("../feature/node/NodeStatsCleanupHandler");
const NodeStatsCheckHandler_1 = require("../feature/node/NodeStatsCheckHandler");
const ProcessNodePoolHandler_1 = require("../feature/nodepool/ProcessNodePoolHandler");
jest.mock('@jfrog-pipelines/configuration', () => {
    return {
        ConfigFactory: { config: { allowDynamicNodes: true, allowCustomNodes: true } }
    };
});
jest.mock('@jfrog-pipelines/redis', () => ({ RedisClientFactory: { client: {} } }));
jest.mock('../feature/node/NodeStatsCheckHandler');
const store = microservice_1.applicationContext;
store.set(microservice_1.SYSTEM_SERVICE_INSTANCE_INITIALIZER, { systemServiceInstancesId: 1 });
describe('Command Factory Test', () => {
    it('should return handler instance for NodeStatsCheckHandler', () => {
        const payload = {
            payload: {
                eventType: utility_1.Actor.NODE_STATS_CHECK,
                payload: null
            }
        };
        const handler = CommandFactory_1.CommandFactory.getHandler(utility_1.ServiceMeta[11], payload);
        expect(handler).toBeInstanceOf(NodeStatsCheckHandler_1.NodeStatsCheckHandler);
    });
    it('should throw error for eventType which is not supported', () => {
        const payload = {
            payload: {
                eventType: 'Invalid EventType',
                payload: null
            }
        };
        expect(() => CommandFactory_1.CommandFactory.getHandler(utility_1.ServiceMeta[11], payload)).toThrow(node_assert_1.AssertionError);
    });
    it('should return handler instance for NodeStatsCleanupHandler', () => {
        const payload = {
            payload: {
                eventType: utility_1.Actor.NODE_STATS_DELETE,
                payload: null
            }
        };
        const handler = CommandFactory_1.CommandFactory.getHandler(utility_1.ServiceMeta[11], payload);
        expect(handler).toBeInstanceOf(NodeStatsCleanupHandler_1.NodeStatsCleanupHandler);
    });
    it('should return handler instance for ProcessNodePoolHandler', () => {
        const payload = {
            payload: {
                eventType: utility_1.Actor.NODE_POOL_PROCESSING,
                payload: {
                    id: 1
                }
            }
        };
        const handler = CommandFactory_1.CommandFactory.getHandler(utility_1.ServiceMeta[11], payload);
        expect(handler).toBeInstanceOf(ProcessNodePoolHandler_1.ProcessNodePoolHandler);
    });
    it('should return handler instance for CreateStaticNodeHandler', () => {
        const payload = {
            payload: {
                eventType: utility_1.Actor.CREATE_NODE,
                payload: {
                    id: 1
                }
            }
        };
        const handler = CommandFactory_1.CommandFactory.getHandler(utility_1.ServiceMeta[11], payload);
        expect(handler).toBeInstanceOf(MockClass_1.MockClass);
    });
});
//# sourceMappingURL=CommandFactory.test.js.map