"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const BuildPlaneMessageDao_1 = require("../../../driven/db/BuildPlaneMessageDao");
const JobDomainService_1 = require("../JobDomainService");
describe('Test BuildPlaneService #getMessageCount', () => {
    it('returns 0 if pool id not found', async () => {
        const service = new JobDomainService_1.JobDomainService();
        const dao = new BuildPlaneMessageDao_1.BuildPlaneMessageDao();
        const poolID = 1;
        const spyGetMessageCount = jest.spyOn(BuildPlaneMessageDao_1.BuildPlaneMessageDao.prototype, 'count').mockResolvedValueOnce(0);
        const count = await service.getReadyMessageCount(poolID);
        expect(dao.count).toHaveBeenCalledTimes(1);
        expect(count).toBe(0);
        spyGetMessageCount.mockClear();
    });
    it('returns count if pool id  found', async () => {
        const service = new JobDomainService_1.JobDomainService();
        const dao = new BuildPlaneMessageDao_1.BuildPlaneMessageDao();
        const poolID = 5;
        const spyGetMessageCount = jest.spyOn(BuildPlaneMessageDao_1.BuildPlaneMessageDao.prototype, 'count').mockResolvedValueOnce(1);
        const count = await service.getReadyMessageCount(poolID);
        expect(dao.count).toHaveBeenCalledTimes(1);
        expect(count).toBe(1);
        spyGetMessageCount.mockClear();
    });
});
describe('Test BuildPlaneService #getReadyMessages', () => {
    it('returns buildPlaneMessages when they exist', async () => {
        const service = new JobDomainService_1.JobDomainService();
        const dao = new BuildPlaneMessageDao_1.BuildPlaneMessageDao();
        const expectedResponse = [
            {
                projectId: 1,
                pipelineId: 1,
                runId: 1,
                nodePoolId: 1,
                statusCode: 4015,
                priority: 1000,
                payload: {},
                triggeredAt: new Date()
            }
        ];
        const spyGetMessageCount = jest
            .spyOn(BuildPlaneMessageDao_1.BuildPlaneMessageDao.prototype, 'findAll')
            .mockResolvedValueOnce(expectedResponse);
        const messages = await service.getReadyMessages(1);
        expect(spyGetMessageCount).toHaveBeenCalledTimes(1);
        expect(dao.findAll).toHaveBeenCalledTimes(1);
        expect(messages).toBe(expectedResponse);
    });
    it('returns empty array when no buildPlaneMessages exist', async () => {
        const service = new JobDomainService_1.JobDomainService();
        const dao = new BuildPlaneMessageDao_1.BuildPlaneMessageDao();
        const expectedResponse = [];
        const spyGetMessageCount = jest
            .spyOn(BuildPlaneMessageDao_1.BuildPlaneMessageDao.prototype, 'findAll')
            .mockResolvedValueOnce(expectedResponse);
        const messages = await service.getReadyMessages(1);
        expect(spyGetMessageCount).toHaveBeenCalledTimes(1);
        expect(dao.findAll).toHaveBeenCalledTimes(1);
        expect(messages).toBe(expectedResponse);
    });
});
//# sourceMappingURL=JobDomainService.test.js.map