"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NodeConsoleService = void 0;
const node_util_1 = require("node:util");
const logger_1 = require("@jfrog-pipelines/logger");
const NodeConsoleLedgerService_1 = require("./NodeConsoleLedgerService");
class NodeConsoleService {
    constructor() {
        this.logger = logger_1.LoggerFactory.getLogger();
        this.nodeLedger = new NodeConsoleLedgerService_1.NodeConsoleLedgerService();
    }
    async create(nodeId, messages) {
        try {
            const nodeConsoles = Array.isArray(messages)
                ? messages.map((message) => this.nodeLedger.createNodeConsole(message, nodeId))
                : this.nodeLedger.createNodeConsole(messages, nodeId);
            await this.nodeLedger.insertNodeConsole(nodeConsoles);
        }
        catch (error) {
            this.logger.warn(`Not able to create node consoles for nodeId = ${nodeId} due to error = ${(0, node_util_1.inspect)(error)}`);
        }
    }
    async getAll(nodeId, additionalGetOptions) {
        try {
            const consoles = await this.nodeLedger.getById(nodeId);
            return consoles;
        }
        catch (error) {
            this.logger.warn(`Not able to get node consoles for nodeId = ${nodeId} due to error = ${(0, node_util_1.inspect)(error)}`);
            return [];
        }
    }
}
exports.NodeConsoleService = NodeConsoleService;
//# sourceMappingURL=NodeConsoleService.js.map