"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const data_access_layer_1 = require("@jfrog-pipelines/data-access-layer");
const expect_1 = __importDefault(require("expect"));
const StatsDomainService_1 = require("../StatsDomainService");
const NodeStatsDao_1 = require("../../../driven/db/NodeStatsDao");
jest.mock('@jfrog-pipelines/redis', () => {
    const actualRedis = jest.requireActual('@jfrog-pipelines/redis');
    return {
        ...actualRedis,
        RedisClientFactory: {
            client: {}
        }
    };
});
describe('Node Stats Service Test', () => {
    const nodeStatService = new StatsDomainService_1.StatsDomainService();
    it('should delete node stats', async () => {
        const reportedBefore = '2023-06-03T18:59:35.494Z';
        const query = new data_access_layer_1.SequelizeQueryBuilder({})
            .whereWithOperator('reportedAt', reportedBefore, data_access_layer_1.operatorsKey.$lt)
            .build();
        const nodeStatDaoDeleteSpy = jest.spyOn(NodeStatsDao_1.NodeStatsDao.prototype, 'delete').mockResolvedValue(1);
        await nodeStatService.deleteNodeStats(reportedBefore);
        (0, expect_1.default)(nodeStatDaoDeleteSpy).toHaveBeenCalledTimes(1);
        (0, expect_1.default)(nodeStatDaoDeleteSpy).toHaveBeenCalledWith(query);
    });
    it('should get latest node stats for a nodeId', async () => {
        const nodeId = 1;
        const findOneOutput = {
            id: 35,
            nodeId: 11,
            reportedAt: '2023-06-13T18:32:15.686Z',
            diskUsageInPercentage: '2',
            memoryUsageInPercentage: '99',
            cpuLoadInPercentage: '48',
            activeContainersCount: 5,
            totalContainersCount: 5,
            imageCount: 5,
            projectId: 1,
            createdBy: null,
            updatedBy: null,
            createdAt: '2023-06-13T18:32:15.730Z',
            updatedAt: '2023-06-13T18:32:15.731Z'
        };
        const findOneQuery = {
            where: {
                nodeId: 1
            },
            order: [['reportedAt', 'DESC NULLS LAST']],
            limit: 1
        };
        const findOneSpy = jest.spyOn(NodeStatsDao_1.NodeStatsDao.prototype, 'findOne').mockResolvedValue(findOneOutput);
        await nodeStatService.getLatestNodeStatForNode(nodeId);
        (0, expect_1.default)(findOneSpy).toHaveBeenCalledTimes(1);
        (0, expect_1.default)(findOneSpy).toHaveBeenCalledWith(findOneQuery);
    });
    it('should delete node stats based on nodeId', async () => {
        const nodeId = 1;
        const expectedQuery = {
            where: {
                nodeId: nodeId
            }
        };
        const nodeStatsDaoSpy = jest.spyOn(NodeStatsDao_1.NodeStatsDao.prototype, 'delete').mockImplementation(jest.fn());
        await nodeStatService.deleteByNodeId(nodeId);
        (0, expect_1.default)(nodeStatsDaoSpy).toHaveBeenCalledTimes(1);
        (0, expect_1.default)(nodeStatsDaoSpy).toHaveBeenCalledWith(expectedQuery);
    });
});
//# sourceMappingURL=NodeStatsService.test.js.map