"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Node = exports.PoolKind = void 0;
const utils_1 = require("../../utils");
const vo_1 = require("./vo");
const StatusLastUpdatedAtVo_1 = require("./vo/StatusLastUpdatedAtVo");
const constants_1 = require("./constants");
var PoolKind;
(function (PoolKind) {
    PoolKind["JOB"] = "JOB";
    PoolKind["DEPLOYMENT"] = "DEPLOYMENT";
})(PoolKind = exports.PoolKind || (exports.PoolKind = {}));
class Node {
    constructor({ id, instanceId, currentBuildPlaneVersion, intendedBuildPlaneVersion, statusCode, statusLastUpdatedAt, isAutoInitialized, isDynamicNode, projectIntegrationId, providerMetadataPropertyBag, runtime, instanceInfo }) {
        this.id = new utils_1.GenericVo(id);
        this.instanceId = new utils_1.GenericVo(instanceId);
        this.statusCode = new vo_1.NodeStatusVo(statusCode);
        this.intendedBuildPlaneVersion = new utils_1.GenericVo(intendedBuildPlaneVersion);
        this.currentBuildPlaneVersion = new utils_1.GenericVo(currentBuildPlaneVersion);
        this.statusLastUpdatedAt = new StatusLastUpdatedAtVo_1.StatusLastUpdatedAtVo(statusLastUpdatedAt);
        this.isAutoInitialized = isAutoInitialized;
        this.isDynamicNode = isDynamicNode;
        this.projectIntegrationId = projectIntegrationId;
        this.providerMetadataPropertyBag = providerMetadataPropertyBag;
        this.runtime = runtime;
        this.instanceInfo = instanceInfo ?? {};
    }
    static create(nodes) {
        const NodeEntityCollection = [];
        for (const node of nodes) {
            const nodeEntity = new Node({
                id: `${node.id}`,
                instanceId: node.instanceId,
                currentBuildPlaneVersion: node.currentBuildPlaneVersion,
                intendedBuildPlaneVersion: node.intendedBuildPlaneVersion,
                statusCode: node.statusCode,
                statusLastUpdatedAt: node.statusLastUpdatedAt,
                isAutoInitialized: node.isAutoInitialized,
                isDynamicNode: node.isOnDemand,
                projectIntegrationId: node.projectIntegrationId,
                providerMetadataPropertyBag: node.providerMetadataPropertyBag,
                runtime: node.runtime ?? '',
                instanceInfo: node.instanceInfo
            });
            NodeEntityCollection.push(nodeEntity);
        }
        return NodeEntityCollection;
    }
    getId() {
        return this.id;
    }
    getInstanceId() {
        return this.instanceId;
    }
    getStatusCode() {
        return this.statusCode;
    }
    getCurrentBuildPlaneVersion() {
        return this.currentBuildPlaneVersion;
    }
    getIntendedBuildPlaneVersion() {
        return this.intendedBuildPlaneVersion;
    }
    getstatusLastUpdatedAt() {
        return this.statusLastUpdatedAt;
    }
    getIsAutoInitialized() {
        return this.isAutoInitialized;
    }
    getIsDynamicNode() {
        return this.isDynamicNode;
    }
    getIsStaticNode() {
        return !this.isDynamicNode;
    }
    getProjectIntegrationId() {
        return this.projectIntegrationId;
    }
    getSubscriptionId() {
        return this.providerMetadataPropertyBag.subscriptionId ?? null;
    }
    getPoolKind() {
        return this.runtime ? PoolKind.JOB : PoolKind.DEPLOYMENT;
    }
    getRegion() {
        return this.providerMetadataPropertyBag.region ?? null;
    }
    getImageId() {
        return this.providerMetadataPropertyBag.imageId ?? null;
    }
    getClientToken() {
        const value = this.instanceInfo.clientToken ?? '';
        return new utils_1.GenericVo(value);
    }
    getPriority() {
        return Node.priorityList.indexOf(this.getStatusCode().getValue());
    }
}
exports.Node = Node;
Node.priorityList = [constants_1.NodeStates.Success, constants_1.NodeStates.Cached];
//# sourceMappingURL=Node.js.map