"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getProvisionerTestCases = exports.getMockNodes = void 0;
const NodeDomainService_1 = require("../NodeDomainService");
function addNodes(successNodes, nodes, statusCode) {
    for (let index = 0; index < successNodes; index++) {
        nodes.push({ friendlyName: `${statusCode}${index}`, projectId: 1, nodePoolId: 1, statusCode: statusCode });
    }
}
function getMockNodes({ successNodes, waitingNodes, cachedNodes, processingNodes, failureNodes, stoppedNodes }) {
    const nodes = [];
    addNodes(successNodes, nodes, NodeDomainService_1.NodeStatus.success);
    addNodes(waitingNodes, nodes, NodeDomainService_1.NodeStatus.waiting);
    addNodes(cachedNodes, nodes, NodeDomainService_1.NodeStatus.cached);
    addNodes(processingNodes, nodes, NodeDomainService_1.NodeStatus.processing);
    addNodes(failureNodes, nodes, NodeDomainService_1.NodeStatus.failure);
    addNodes(stoppedNodes, nodes, NodeDomainService_1.NodeStatus.stopped);
    return nodes;
}
exports.getMockNodes = getMockNodes;
function getProvisionerTestCases() {
    return [
        {
            nodeCreated: 0,
            nodeStarted: 0,
            nodeLimit: 0,
            buildPlaneMessageCount: 0,
            successNodes: 0,
            waitingNodes: 0,
            cachedNodes: 0,
            processingNodes: 0,
            failureNodes: 0,
            stoppedNodes: 0
        },
        {
            nodeCreated: 1,
            nodeStarted: 0,
            nodeLimit: 1,
            buildPlaneMessageCount: 1,
            successNodes: 0,
            waitingNodes: 0,
            cachedNodes: 0,
            processingNodes: 0,
            failureNodes: 0,
            stoppedNodes: 0
        },
        {
            nodeCreated: 1,
            nodeStarted: 0,
            nodeLimit: 1,
            buildPlaneMessageCount: 2,
            successNodes: 0,
            waitingNodes: 0,
            cachedNodes: 0,
            processingNodes: 0,
            failureNodes: 0,
            stoppedNodes: 0
        },
        {
            nodeCreated: 1,
            nodeStarted: 1,
            nodeLimit: 2,
            buildPlaneMessageCount: 2,
            successNodes: 0,
            waitingNodes: 0,
            cachedNodes: 1,
            processingNodes: 0,
            failureNodes: 0,
            stoppedNodes: 0
        },
        {
            nodeCreated: 0,
            nodeStarted: 1,
            nodeLimit: 2,
            buildPlaneMessageCount: 2,
            successNodes: 0,
            waitingNodes: 1,
            cachedNodes: 1,
            processingNodes: 0,
            failureNodes: 0,
            stoppedNodes: 0
        },
        {
            nodeCreated: 0,
            nodeStarted: 0,
            nodeLimit: 2,
            buildPlaneMessageCount: 2,
            successNodes: 1,
            waitingNodes: 1,
            cachedNodes: 1,
            processingNodes: 0,
            failureNodes: 0,
            stoppedNodes: 0
        },
        {
            nodeCreated: 0,
            nodeStarted: 0,
            nodeLimit: 3,
            buildPlaneMessageCount: 3,
            successNodes: 1,
            waitingNodes: 1,
            cachedNodes: 1,
            processingNodes: 1,
            failureNodes: 0,
            stoppedNodes: 0
        },
        {
            nodeCreated: 1,
            nodeStarted: 1,
            nodeLimit: 5,
            buildPlaneMessageCount: 5,
            successNodes: 2,
            waitingNodes: 0,
            cachedNodes: 1,
            processingNodes: 1,
            failureNodes: 1,
            stoppedNodes: 1
        },
        {
            nodeCreated: 0,
            nodeStarted: 4,
            nodeLimit: 5,
            buildPlaneMessageCount: 10,
            successNodes: 0,
            waitingNodes: 0,
            cachedNodes: 9,
            processingNodes: 1,
            failureNodes: 1,
            stoppedNodes: 1
        },
        {
            nodeCreated: 0,
            nodeStarted: 0,
            nodeLimit: 5,
            buildPlaneMessageCount: 10,
            successNodes: 9,
            waitingNodes: 0,
            cachedNodes: 1,
            processingNodes: 1,
            failureNodes: 1,
            stoppedNodes: 1
        },
        {
            nodeCreated: 1,
            nodeStarted: 0,
            nodeLimit: 11,
            buildPlaneMessageCount: 10,
            successNodes: 9,
            waitingNodes: 0,
            cachedNodes: 0,
            processingNodes: 1,
            failureNodes: 1,
            stoppedNodes: 1
        },
        {
            nodeCreated: 0,
            nodeStarted: 0,
            nodeLimit: 11,
            buildPlaneMessageCount: 10,
            successNodes: 9,
            waitingNodes: 10,
            cachedNodes: 0,
            processingNodes: 1,
            failureNodes: 1,
            stoppedNodes: 1
        },
        {
            nodeCreated: 0,
            nodeStarted: 0,
            nodeLimit: 0,
            buildPlaneMessageCount: 1,
            successNodes: 0,
            waitingNodes: 0,
            cachedNodes: 0,
            processingNodes: 0,
            failureNodes: 0,
            stoppedNodes: 0
        },
        {
            nodeCreated: 0,
            nodeStarted: 1,
            nodeLimit: 1,
            buildPlaneMessageCount: 1,
            successNodes: 0,
            waitingNodes: 0,
            cachedNodes: 1,
            processingNodes: 0,
            failureNodes: 0,
            stoppedNodes: 0
        },
        {
            nodeCreated: 0,
            nodeStarted: 0,
            nodeLimit: 5,
            buildPlaneMessageCount: 10,
            successNodes: 5,
            waitingNodes: 0,
            cachedNodes: 0,
            processingNodes: 0,
            failureNodes: 0,
            stoppedNodes: 0
        },
        {
            nodeCreated: 0,
            nodeStarted: 0,
            nodeLimit: 5,
            buildPlaneMessageCount: 10,
            successNodes: 0,
            waitingNodes: 5,
            cachedNodes: 0,
            processingNodes: 0,
            failureNodes: 0,
            stoppedNodes: 0
        },
        {
            nodeCreated: 0,
            nodeStarted: 5,
            nodeLimit: 5,
            buildPlaneMessageCount: 10,
            successNodes: 0,
            waitingNodes: 0,
            cachedNodes: 5,
            processingNodes: 0,
            failureNodes: 0,
            stoppedNodes: 0
        },
        {
            nodeCreated: 0,
            nodeStarted: 0,
            nodeLimit: 5,
            buildPlaneMessageCount: 10,
            successNodes: 0,
            waitingNodes: 0,
            cachedNodes: 0,
            processingNodes: 5,
            failureNodes: 0,
            stoppedNodes: 0
        },
        {
            nodeCreated: 0,
            nodeStarted: 1,
            nodeLimit: 1,
            buildPlaneMessageCount: 1,
            successNodes: 0,
            waitingNodes: 0,
            cachedNodes: 1,
            processingNodes: 0,
            failureNodes: 0,
            stoppedNodes: 0
        },
        {
            nodeCreated: 0,
            nodeStarted: 0,
            nodeLimit: 10,
            buildPlaneMessageCount: 20,
            successNodes: 15,
            waitingNodes: 0,
            cachedNodes: 1,
            processingNodes: 0,
            failureNodes: 0,
            stoppedNodes: 0
        }
    ].map((values) => Object.values(values));
}
exports.getProvisionerTestCases = getProvisionerTestCases;
//# sourceMappingURL=NodeProvisionerTestCases.js.map