"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DriverFactory = void 0;
const configuration_1 = require("@jfrog-pipelines/configuration");
const NodePool_1 = require("../../nodepool/NodePool");
const providers_1 = require("./providers");
const InstanceVariables_1 = require("./InstanceVariables");
class DriverFactory {
    getProvider(node, nodePool) {
        const { formJSONValues } = nodePool.getProjectIntegrationResponse();
        const providerName = nodePool.getCloudProviderName();
        const integrationValues = this.transformFormJSONValues(formJSONValues);
        const subscriptionId = node.getSubscriptionId();
        if (subscriptionId) {
            integrationValues.subscriptionId = subscriptionId;
        }
        const isSaas = configuration_1.ConfigFactory.config.isSaaS;
        const customerName = configuration_1.ConfigFactory.config.getCustom('runtime.saasCustomerName');
        const saasEnvironment = configuration_1.ConfigFactory.config.getCustom('runtime.saasEnvironment');
        const instanceVariables = new InstanceVariables_1.InstanceVariables(isSaas, customerName, saasEnvironment);
        if (providerName === NodePool_1.CloudProvider.AWS) {
            const credentials = {
                accessKeyId: integrationValues.accessKeyId,
                secretAccessKey: integrationValues.secretAccessKey,
                region: integrationValues.region
            };
            return providers_1.AwsDriver.create(credentials, instanceVariables, node, nodePool);
        }
        throw new Error(`Provider ${providerName} not supported`);
    }
    transformFormJSONValues(formValues) {
        const formKeyValues = {};
        for (const values of formValues) {
            formKeyValues[values.label] = values.value;
        }
        return formKeyValues;
    }
}
exports.DriverFactory = DriverFactory;
//# sourceMappingURL=DriverFactory.js.map