"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AwsRequestTransformer = void 0;
const node_path_1 = __importDefault(require("node:path"));
const node_util_1 = require("node:util");
const metadata_1 = require("@jfrog-pipelines/metadata");
const cloud_1 = require("@jfrog-pipelines/cloud");
const logger_1 = require("@jfrog-pipelines/logger");
const utility_1 = require("@jfrog-pipelines/utility");
const userService_1 = require("../../../driven/acl/userService");
class AwsRequestTransformer {
    constructor(runMode, externalApiUrl, nodePollerIntervalMS, noVerifySsl, isCustomCertsEnabled, customCertsData) {
        this.runMode = runMode;
        this.externalApiUrl = externalApiUrl;
        this.nodePollerIntervalMS = nodePollerIntervalMS;
        this.noVerifySsl = noVerifySsl;
        this.isCustomCertsEnabled = isCustomCertsEnabled;
        this.customCertsData = customCertsData;
        this.logger = logger_1.LoggerFactory.getLogger('AwsRequestTransformer');
        this.userRepository = new userService_1.UserRepository();
    }
    async getNodeCreateRequest(nodePool, node) {
        const project = await this.userRepository.getProjectById(nodePool.projectId);
        const nodeUserData = await this.getNodeBootTemplate(nodePool, node);
        const encodedNodeUserData = Buffer.from(nodeUserData).toString('base64');
        const imageId = node.providerMetadataPropertyBag?.imageId;
        const instanceRequest = new cloud_1.CreateInstanceRequest(node.id, nodePool.providerMetadataPropertyBag.instanceSize, nodePool.operatingSystem, nodePool.id, nodePool.projectId, nodePool.projectIntegrationId, node.friendlyName, project.name, nodePool.name, nodePool.architecture, encodedNodeUserData, imageId, nodePool.providerMetadataPropertyBag?.keyPairName, nodePool.providerMetadataPropertyBag?.customTags, '', nodePool.diskSizeinGB, nodePool.providerMetadataPropertyBag?.resourceGroupName, nodePool.providerMetadataPropertyBag?.vnetName, undefined, undefined, nodePool.providerMetadataPropertyBag.publicSshKey, nodePool.providerMetadataPropertyBag.subnetId, nodePool.providerMetadataPropertyBag.securityGroupId);
        return instanceRequest;
    }
    getNodeDeleteRequest(node) {
        return new cloud_1.TerminateInstanceRequest([node.instanceId]);
    }
    getNodeTransitionRequest(node) {
        return new cloud_1.InstanceStateRequest(node.instanceId);
    }
    async getNodeUserData(nodePool, node) {
        const urlConfig = await this.userRepository.getUnifiedUiAndWwwUrl();
        const buildPlaneArtifactExtension = metadata_1.NodeMetadata.getBuildPlaneArtifactExtension(nodePool.architecture, nodePool.operatingSystem);
        const downloadImageUrl = `${urlConfig.rtUiUrl}/pipelines/webapp/buildPlane-${nodePool.architecture}-${nodePool.operatingSystem}.${buildPlaneArtifactExtension}`;
        const token = node.systemPropertyBag.token;
        let insecureDockerRegistries = JSON.stringify([]);
        if (nodePool.initPropertyBag?.insecureDockerRegistries) {
            insecureDockerRegistries = JSON.stringify(nodePool.initPropertyBag?.insecureDockerRegistries);
        }
        return {
            nodeId: node.id,
            projectId: nodePool.projectId,
            buildPlaneVersion: node.intendedBuildPlaneVersion,
            apiExternalUrl: this.externalApiUrl,
            baseUrlUI: urlConfig.rtUiUrl,
            runMode: this.runMode,
            architecture: nodePool.architecture,
            operatingSystem: nodePool.operatingSystem,
            buildPlaneArtifactDownloadUrl: downloadImageUrl,
            configureNode: false,
            installPrereqs: false,
            isSwapEnabled: false,
            token: token,
            nodePollerIntervalMS: this.nodePollerIntervalMS,
            noVerifySsl: this.noVerifySsl,
            customCertsEnabled: this.isCustomCertsEnabled,
            customCertsData: this.customCertsData && JSON.stringify(this.customCertsData),
            rootUserInit: !nodePool.initAsNonRoot,
            diskSizeinGB: nodePool.diskSizeinGB,
            insecureDockerRegistries: insecureDockerRegistries
        };
    }
    async getNodeBootTemplate(nodePool, node) {
        const templatePath = node_path_1.default.join(__dirname, `templates/userData.tpl`);
        try {
            const userData = await this.getNodeUserData(nodePool, node);
            return (0, utility_1.renderTemplate)(templatePath, userData);
        }
        catch (error) {
            this.logger.error(`Failed to load template due to error: ${(0, node_util_1.inspect)(error)}`);
            throw error;
        }
    }
}
exports.AwsRequestTransformer = AwsRequestTransformer;
//# sourceMappingURL=AwsRequestTransformer.js.map