{{#if (eq operatingSystem 'WindowsServer_2019') }}
<powershell>
$ErrorActionPreference = "stop"
# Exporting env variables required for booting reqKick inside AZ VM
# NOTE: this file cannot be more than 16KB
if (!"$JFROG_DIR") {
  New-Variable -Name JFROG_DIR -Scope Global -Option ReadOnly -Value "$env:PROGRAMDATA\jfrog\pipelines" -Force
}

New-Variable -Name REQKICK_DIR -Scope Global -Option ReadOnly -Value "$JFROG_DIR\reqKick" -Force
New-Variable -Name EXECTEMPLATES_DIR -Scope Global -Option ReadOnly -Value "$REQKICK_DIR\node_modules\@jfrog-pipelines/core\execTemplates" -Force
New-Variable -Name EXTENSIONS_DIR -Scope Global -Option ReadOnly -Value "$JFROG_DIR\extensions" -Force
New-Variable -Name REQEXEC_DIR -Scope Global -Option ReadOnly -Value "$JFROG_DIR\reqExec" -Force
New-Variable -Name REPORTS_DIR -Scope Global -Option ReadOnly -Value "$JFROG_DIR\reports" -Force
New-Variable -Name NODEINIT_DIR -Scope Global -Option ReadOnly -Value "$JFROG_DIR\nodeInit" -Force
New-Variable -Name REQKICK_SERVICE_NAME -Scope Global -Option ReadOnly -Value "pipelines-reqKick" -Force
New-Variable -Name CUSTOM_CERTS_DIR -Scope Global -Option ReadOnly -Value "$JFROG_DIR\var\etc\security\keys\trusted" -Force

New-Variable -Name BUILDPLANE_TAR_DOWNLOAD_URL -Scope Global -Value "{{buildPlaneArtifactDownloadUrl}}" -Force
New-Variable -Name NODE_OPERATING_SYSTEM -Scope Global -Value "{{operatingSystem}}" -Force
New-Variable -Name NODE_ARCHITECTURE -Scope Global -Value "{{architecture}}" -Force
New-Variable -Name RUN_MODE -Scope Global -Value "{{runMode}}" -Force
New-Variable -Name NODE_ID -Scope Global -Value "{{nodeId}}" -Force
New-Variable -Name PROJECT_ID -Scope Global -Value "{{projectId}}" -Force
New-Variable -Name BUILD_PLANE_VERSION -Scope Global -Value "{{buildPlaneVersion}}" -Force
New-Variable -Name PIPELINES_SHARED_ARTIFACTORY_BASEURLUI -Scope Global -Value "{{baseUrlUI}}" -Force
New-Variable -Name PIPELINES_CORE_SERVICES_API_EXTERNALURL -Scope Global -Value "{{apiExternalUrl}}" -Force
New-Variable -Name INSECURE_DOCKER_REGISTRIES -Scope Global -Value '{{{insecureDockerRegistries}}}' -Force
New-Variable -Name PIPELINES_NODE_API_TOKEN -Scope Global -Value "{{token}}" -Force
New-Variable -Name NODE_POLLER_INTERVAL_MS -Scope Global -Value {{nodePollerIntervalMS}} -Force
New-Variable -Name CUSTOM_CERTS_ENABLED -Scope Global -Value {{customCertsEnabled}} -Force
if ($CUSTOM_CERTS_ENABLED -eq "true") {
  New-Variable -Name CUSTOM_CERTS_DATA -Scope Global -Value {{{customCertsData}}} -Force
} else {
  New-Variable -Name CUSTOM_CERTS_DATA -Scope Global -Value "" -Force
}

$headers = @{}
$headers['Authorization'] = "Bearer $PIPELINES_NODE_API_TOKEN"

New-Variable -Name BOOT_BUILD_AGENT -Scope Global -Value $TRUE -Force
New-Variable -Name CONFIGURE_NODE -Scope Global -Value $FALSE -Force
New-Variable -Name INITIALIZE_NODE -Scope Global -Value $FALSE -Force

if ($CUSTOM_CERTS_ENABLED -eq "true") {
  Set-Variable -Name CUSTOM_CERTS_ENABLED -Value $TRUE -Force
  New-Item "$CUSTOM_CERTS_DIR" -ItemType Directory -Force
  echo $CUSTOM_CERTS_DATA.replace("\n", "`n") | Out-File -Encoding utf8 "$CUSTOM_CERTS_DIR\ca.crt"

  # In windows, we can add cert one by one. Hence splitting the files to
  # individual cert files.
  $Pattern = "(?smi)^-{2,}BEGIN CERTIFICATE-{2,}.*?-{2,}END CERTIFICATE-{2,}"
  Get-Content "$CUSTOM_CERTS_DIR\ca.crt" -raw |
    Select-String  -Pattern $Pattern -Allmatches|
      ForEach-Object {$Cnt=0;$_.Matches}| ForEach-Object {
        $Cnt++
        Set-Content -Value $_.Value -Path ("$CUSTOM_CERTS_DIR\ca{0}.crt" -f $Cnt)
      }
  Remove-Item "$CUSTOM_CERTS_DIR\ca.crt"
  $Files = Get-ChildItem $CUSTOM_CERTS_DIR
  foreach ($F in $Files) {
    certutil -addstore -f "ROOT" "$CUSTOM_CERTS_DIR\$F"
  }
} else {
  Set-Variable -Name CUSTOM_CERTS_ENABLED -Value $FALSE -Force
}

if (Get-Command "nssm" -ErrorAction SilentlyContinue) {
  Get-Service pipelines-reqKick -ErrorAction SilentlyContinue | %{
    if ($_.Status -eq "Running") {
      nssm stop $_.Name
    }
  }
}

Invoke-Webrequest -Headers $headers -Uri $BUILDPLANE_TAR_DOWNLOAD_URL -Outfile buildPlane.tar.gz

if (Test-Path "$env:PROGRAMDATA\jfrog\pipelines") {
  Remove-Item "$env:PROGRAMDATA\jfrog\pipelines" -Recurse;
}
New-Item -ItemType directory -path "$env:PROGRAMDATA\jfrog\pipelines" -Force
tar -xf buildPlane.tar.gz -C "$env:PROGRAMDATA\jfrog\pipelines"

. $NODEINIT_DIR/$NODE_ARCHITECTURE/$NODE_OPERATING_SYSTEM/boot.ps1

$Jsonbody= @{
    'lastInitializedAt' =  Get-Date -Format yyyy-MM-ddTHH:mm:ssZ
    } | ConvertTo-Json

try {
    $Response = Invoke-RestMethod -Method Put -Headers $headers -ContentType 'application/json' -Uri "$PIPELINES_CORE_SERVICES_API_EXTERNALURL/nodes/$NODE_ID" -Body $Jsonbody -ErrorAction Stop
    $StatusCode = $Response.StatusCode
}
catch{
    $StatusCode = $Response
}
</powershell>
{{else}}
#!/bin/bash -e
# Exporting env variables required for booting reqKick inside EC2 instance
# NOTE: this file cannot be more than 16KB
{{#if (eq operatingSystem 'Ubuntu_18.04') }}
export ROOT_USER_INIT={{rootUserInit}}
if [ -z "$JFROG_DIR" ]; then
  if [ "$ROOT_USER_INIT" == true ]; then
    export JFROG_DIR="/var/opt/jfrog/pipelines"
  else
    export USERNAME="pipelinesRootless"
    export JFROG_DIR="/home/$USERNAME/.jfrog/pipelines"
  fi
fi
{{/if}}
{{#if (eq operatingSystem 'Ubuntu_20.04') }}
export ROOT_USER_INIT={{rootUserInit}}
if [ -z "$JFROG_DIR" ]; then
  if [ "$ROOT_USER_INIT" == true ]; then
    export JFROG_DIR="/var/opt/jfrog/pipelines"
  else
    export USERNAME="pipelinesRootless"
    export JFROG_DIR="/home/$USERNAME/.jfrog/pipelines"
  fi
fi
{{/if}}
{{#if (eq operatingSystem 'Ubuntu_22.04') }}
export ROOT_USER_INIT={{rootUserInit}}
if [ -z "$JFROG_DIR" ]; then
  if [ "$ROOT_USER_INIT" == true ]; then
    export JFROG_DIR="/var/opt/jfrog/pipelines"
  else
    export USERNAME="pipelinesRootless"
    export JFROG_DIR="/home/$USERNAME/.jfrog/pipelines"
  fi
fi
{{/if}}

{{#if (eq operatingSystem 'CentOS_7') }}
export JFROG_DIR="/var/opt/jfrog/pipelines"
{{/if}}

{{#if (eq operatingSystem 'MacOS_13.5') }}
export JFROG_DIR="/var/opt/jfrog/pipelines"
{{/if}}


export REQKICK_DIR="$JFROG_DIR/reqKick"
export EXECTEMPLATES_DIR="$REQKICK_DIR/node_modules/@jfrog-pipelines/core/execTemplates"
export EXTENSIONS_DIR="$JFROG_DIR/extensions"
export REQEXEC_DIR="$JFROG_DIR/reqExec"
export REPORTS_DIR="$JFROG_DIR/reports"
export NODEINIT_DIR="$JFROG_DIR/nodeInit"
export REQKICK_CONFIG_DIR="$JFROG_DIR/var/etc/reqKick"
export REQKICK_SERVICE_NAME="pipelines-reqKick"
export CUSTOM_CERTS_DIR="$JFROG_DIR/var/etc/security/keys/trusted"
export CUSTOM_CERTS_FILE_LOC="/etc/ssl/certs/ca-certificates.crt"
export NODE_OPERATING_SYSTEM="{{operatingSystem}}"
export NODE_ARCHITECTURE="{{architecture}}"
export RUN_MODE="{{runMode}}"
export NODE_ID="{{nodeId}}"
export PROJECT_ID="{{projectId}}"
export BUILD_PLANE_VERSION="{{buildPlaneVersion}}"
export BUILDPLANE_DOWNLOAD_URL="{{buildPlaneArtifactDownloadUrl}}"
export PIPELINES_SHARED_ARTIFACTORY_BASEURLUI="{{baseUrlUI}}"
export PIPELINES_CORE_SERVICES_API_EXTERNALURL="{{apiExternalUrl}}"
export CONFIGURE_NODE=false
export ENABLE_SWAP=false
export BOOT_BUILD_AGENT=true
export AIRGAPPED_INSTALLATION=false
export INSECURE_DOCKER_REGISTRIES='{{{insecureDockerRegistries}}}'
export PIPELINES_NODE_API_TOKEN='{{token}}'
export NODE_POLLER_INTERVAL_MS={{nodePollerIntervalMS}}
export NO_VERIFY_SSL={{noVerifySsl}}
export CUSTOM_CERTS_DATA={{{customCertsData}}}
export CUSTOM_CERTS_ENABLED={{customCertsEnabled}}

node_status_handler() {
    # echo "An error occurred: $1"
    # Perform any necessary actions to handle the error

    # Make the curl call to report the error
    timestamp=$(date '+%s')
    consoleID=$(uuidgen)
    curl --location --request POST "$PIPELINES_SHARED_ARTIFACTORY_BASEURLUI/pipelines/api/v1/nodeConsoles" \
    --header "Authorization: Bearer $PIPELINES_NODE_API_TOKEN" \
    --header 'Content-Type: application/json' \
    --data "{
        \"nodeConsoleModels\": [
            {
                \"nodeId\": \"$NODE_ID\",
                \"consoleId\": \"$consoleID\",
                \"parentConsoleId\": \"root\",
                \"timestamp\": \"$timestamp\",
                \"projectId\": \"$PROJECT_ID\",
                \"type\": \"msg\",
                \"message\": \"$1\",
                \"timestampEndedAt\": null,
                \"isSuccess\": false,
                \"isShown\": null
            }
        ]
    }"
}

downloadNodeAgent() {
  {
    curl -A "reqKick $BUILD_PLANE_VERSION" -H "Authorization: Bearer $PIPELINES_NODE_API_TOKEN" $BUILDPLANE_DOWNLOAD_URL $CURL_OPTS --output $1
    node_status_handler "Successfully downloaded $BUILDPLANE_DOWNLOAD_URL"
  } || {
    node_status_handler "Failed to download $BUILDPLANE_DOWNLOAD_URL"
  }
}

node_status_handler "initializing user data"
CURL_OPTS=""
if [ "$CUSTOM_CERTS_ENABLED" == true ]; then
  mkdir -p $CUSTOM_CERTS_DIR
  echo -e $CUSTOM_CERTS_DATA > $CUSTOM_CERTS_DIR/ca.crt
  {{#if (eq operatingSystem 'CentOS_7') }}
    cp $CUSTOM_CERTS_DIR/ca.crt /usr/share/pki/ca-trust-source/anchors/
    update-ca-trust extract
  {{/if}}
  {{#if (eq operatingSystem 'Ubuntu_18.04') }}
    cp $CUSTOM_CERTS_DIR/ca.crt /usr/local/share/ca-certificates/
    update-ca-certificates
  {{/if}}
  {{#if (eq operatingSystem 'Ubuntu_20.04') }}
    cp $CUSTOM_CERTS_DIR/ca.crt /usr/local/share/ca-certificates/
    update-ca-certificates
  {{/if}}
  {{#if (eq operatingSystem 'Ubuntu_22.04') }}
    cp $CUSTOM_CERTS_DIR/ca.crt /usr/local/share/ca-certificates/
    update-ca-certificates
  {{/if}}
  {{#if (eq operatingSystem 'MacOS_13.5') }}
  security add-trusted-cert -d -r trustRoot -k /Library/Keychains/System.keychain $CUSTOM_CERTS_DIR/ca.crt
  {{/if}}
elif [ "$NO_VERIFY_SSL" == true ]; then
  CURL_OPTS="--insecure"
fi

mkdir -p $JFROG_DIR
node_status_handler "attempting download $BUILDPLANE_DOWNLOAD_URL"


{{#if (eq operatingSystem 'Ubuntu_18.04') }}
downloadNodeAgent buildPlane.deb
if [ "$ROOT_USER_INIT" == true ]; then
  if [ "$JFROG_DIR" == "/var/opt/jfrog/pipelines" ]; then
    dpkg -i buildPlane.deb
  else
    mkdir -p $JFROG_DIR
    dpkg -i --instdir=$JFROG_DIR buildPlane.deb
    mv $JFROG_DIR/var/opt/jfrog/pipelines/* $JFROG_DIR
  fi
  source $NODEINIT_DIR/$NODE_ARCHITECTURE/$NODE_OPERATING_SYSTEM/boot.sh
else
  mkdir -p /home/$USERNAME/.jfrog/pipelines
  mkdir -p /home/$USERNAME/.local/share/docker
  mkdir -p /home/$USERNAME/.config/systemd/user
  mkdir -p /home/$USERNAME/.jfrog/pipelines/var/etc/reqKick
  dpkg -x buildPlane.deb /home/$USERNAME/.jfrog/pipelines

  if [ ! -d /home/$USERNAME/.jfrog/pipelines/extensions ]; then
    mv -f /home/$USERNAME/.jfrog/pipelines/var/opt/jfrog/pipelines/* /home/$USERNAME/.jfrog/pipelines
  fi

  export XDG_RUNTIME_DIR=/run/user/1066
  export HOME=/home/$USERNAME
  export PATH=/home/$USERNAME/bin:$PATH
  export DOCKER_HOST=unix://$XDG_RUNTIME_DIR/docker.sock
  $NODEINIT_DIR/$NODE_ARCHITECTURE/$NODE_OPERATING_SYSTEM/boot.sh $ROOT_USER_INIT /home/$USERNAME
fi

if [ "$ROOT_USER_INIT" == true ]; then
  sudo -E $NODEINIT_DIR/{{architecture}}/{{operatingSystem}}/boot.sh
else
  sudo -E -u $USERNAME $NODEINIT_DIR/$NODE_ARCHITECTURE/$NODE_OPERATING_SYSTEM/boot.sh $ROOT_USER_INIT /home/$USERNAME
fi
{{/if}}
{{#if (eq operatingSystem 'Ubuntu_20.04') }}
downloadNodeAgent buildPlane.deb
if [ "$ROOT_USER_INIT" == true ]; then
  if [ "$JFROG_DIR" == "/var/opt/jfrog/pipelines" ]; then
    node_status_handler "Installing buildPlane.deb"
    dpkg -i buildPlane.deb
  else
    mkdir -p $JFROG_DIR
    dpkg -i --instdir=$JFROG_DIR buildPlane.deb
    mv $JFROG_DIR/var/opt/jfrog/pipelines/* $JFROG_DIR
  fi
  source $NODEINIT_DIR/$NODE_ARCHITECTURE/$NODE_OPERATING_SYSTEM/boot.sh
else
  mkdir -p /home/$USERNAME/.jfrog/pipelines
  mkdir -p /home/$USERNAME/.local/share/docker
  mkdir -p /home/$USERNAME/.config/systemd/user
  mkdir -p /home/$USERNAME/.jfrog/pipelines/var/etc/reqKick
  dpkg -x buildPlane.deb /home/$USERNAME/.jfrog/pipelines

  if [ ! -d /home/$USERNAME/.jfrog/pipelines/extensions ]; then
    mv -f /home/$USERNAME/.jfrog/pipelines/var/opt/jfrog/pipelines/* /home/$USERNAME/.jfrog/pipelines
  fi

  export XDG_RUNTIME_DIR=/run/user/1066
  export HOME=/home/$USERNAME
  export PATH=/home/$USERNAME/bin:$PATH
  export DOCKER_HOST=unix://$XDG_RUNTIME_DIR/docker.sock
  $NODEINIT_DIR/$NODE_ARCHITECTURE/$NODE_OPERATING_SYSTEM/boot.sh $ROOT_USER_INIT /home/$USERNAME
fi

if [ "$ROOT_USER_INIT" == true ]; then
  sudo -E $NODEINIT_DIR/{{architecture}}/{{operatingSystem}}/boot.sh
else
  sudo -E -u $USERNAME $NODEINIT_DIR/$NODE_ARCHITECTURE/$NODE_OPERATING_SYSTEM/boot.sh $ROOT_USER_INIT /home/$USERNAME
fi
{{/if}}
{{#if (eq operatingSystem 'Ubuntu_22.04') }}
downloadNodeAgent buildPlane.deb
if [ "$ROOT_USER_INIT" == true ]; then
  node_status_handler "Value of ROOT_USER_INIT $ROOT_USER_INIT"
  if [ "$JFROG_DIR" == "/var/opt/jfrog/pipelines" ]; then
    node_status_handler "Installing buildPlane.deb"
    dpkg -i buildPlane.deb
  else
    mkdir -p $JFROG_DIR
    dpkg -i --instdir=$JFROG_DIR buildPlane.deb
    mv $JFROG_DIR/var/opt/jfrog/pipelines/* $JFROG_DIR
  fi
  source $NODEINIT_DIR/$NODE_ARCHITECTURE/$NODE_OPERATING_SYSTEM/boot.sh
else
  mkdir -p /home/$USERNAME/.jfrog/pipelines
  mkdir -p /home/$USERNAME/.local/share/docker
  mkdir -p /home/$USERNAME/.config/systemd/user
  mkdir -p /home/$USERNAME/.jfrog/pipelines/var/etc/reqKick
  dpkg -x buildPlane.deb /home/$USERNAME/.jfrog/pipelines

  if [ ! -d /home/$USERNAME/.jfrog/pipelines/extensions ]; then
    mv -f /home/$USERNAME/.jfrog/pipelines/var/opt/jfrog/pipelines/* /home/$USERNAME/.jfrog/pipelines
  fi

  export XDG_RUNTIME_DIR=/run/user/1066
  export HOME=/home/$USERNAME
  export PATH=/home/$USERNAME/bin:$PATH
  export DOCKER_HOST=unix://$XDG_RUNTIME_DIR/docker.sock
  $NODEINIT_DIR/$NODE_ARCHITECTURE/$NODE_OPERATING_SYSTEM/boot.sh $ROOT_USER_INIT /home/$USERNAME
fi

{{/if}}
{{#if (eq operatingSystem 'CentOS_7') }}
downloadNodeAgent buildPlane.rpm
rpm -i --prefix=$JFROG_DIR --force buildPlane.rpm
source $NODEINIT_DIR/$NODE_ARCHITECTURE/$NODE_OPERATING_SYSTEM/boot.sh
{{/if}}
{{#if (eq operatingSystem 'MacOS_13.5') }}
response_code=""
mkdir -p $JFROG_DIR

while true; do
  {
    response_code=$(curl -H "Authorization: Bearer $PIPELINES_NODE_API_TOKEN" $BUILDPLANE_DOWNLOAD_URL $CURL_OPTS --output $JFROG_DIR/buildPlane.tar.gz -L -s -w "%{http_code}")
    [ $response_code -eq 200 ] && break;
  } || {
    echo "$response_code retrying download in 30 seconds..."
    sleep 30
  }
done

tar -xf $JFROG_DIR/buildPlane.tar.gz -C "$JFROG_DIR"

rm $JFROG_DIR/buildPlane.tar.gz

sudo -E $NODEINIT_DIR/{{architecture}}/{{operatingSystem}}/boot.sh
{{/if}}

init_time=$(date -u +"%FT%TZ")
api_response_code=$(curl -s $CURL_OPTS -X PUT -H "Authorization: Bearer $PIPELINES_NODE_API_TOKEN" -H "Content-Type: application/json" -d '{"lastInitializedAt":"'$init_time'"}' $PIPELINES_CORE_SERVICES_API_EXTERNALURL"/nodes/"$NODE_ID -o -l -i -w "%{http_code}")
echo $api_response_code
node_status_handler "Successfully initialized user data"

{{/if}}
