"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SshExecutor = void 0;
const node_util_1 = require("node:util");
const ssh2_1 = require("ssh2");
const logger_1 = require("@jfrog-pipelines/logger");
class SshExecutor {
    constructor(connectionConfig, nodeId) {
        this.connectionConfig = connectionConfig;
        this.nodeId = nodeId;
        this.logger = logger_1.LoggerFactory.getLogger('Nexec');
    }
    connect(nodeLoggerFunction) {
        return new Promise((resolve, reject) => {
            nodeLoggerFunction(`Initializing sshExecutor`, this.nodeId);
            const sshClient = new ssh2_1.Client().connect(this.connectionConfig);
            sshClient.on('error', (error) => {
                nodeLoggerFunction(`error connecting to ssh client ${(0, node_util_1.inspect)(error)}`, this.nodeId);
                reject(new Error(`error connecting to ssh client ${(0, node_util_1.inspect)(error)}`));
            });
            sshClient.on('ready', () => {
                sshClient.sftp((error) => {
                    if (error) {
                        nodeLoggerFunction(`Failed to init sftp due to error :${error.message}`, this.nodeId);
                        reject(new Error(`Failed to init sftp due to error :${error.message}`));
                        return;
                    }
                    this.sshClient = sshClient;
                    nodeLoggerFunction(`Successfully initialized sshExecutor`, this.nodeId);
                    resolve();
                });
            });
        });
    }
    exec(command, label, nodeLoggerFunction) {
        if (!this.sshClient) {
            throw new Error('Ssh client is not initialized. Please initialize with .connect()');
        }
        return new Promise((resolve, reject) => {
            nodeLoggerFunction(label, this.nodeId);
            this.sshClient.exec(command, (error, channel) => {
                if (error) {
                    nodeLoggerFunction(`Failed to ${label} ${(0, node_util_1.inspect)(error)}`, this.nodeId);
                    throw new Error(`Failed to ${label} due to error ${(0, node_util_1.inspect)(error)}`);
                }
                channel.stderr.on('data', (data) => {
                    nodeLoggerFunction(data.toString(), this.nodeId);
                });
                channel.stdout.on('data', (data) => {
                    nodeLoggerFunction(data.toString(), this.nodeId);
                });
                channel.on('exit', (exit) => {
                    const error = exit > 0 ? `exit code: ${exit}` : null;
                    if (exit == 0) {
                        nodeLoggerFunction(`Successfully completed ${label}`, this.nodeId);
                        this.logger.debug(`Successfully completed the ${label}`);
                        resolve();
                    }
                    else {
                        nodeLoggerFunction(`Failed to do ${label} with exit code: ${exit}`, this.nodeId);
                        this.logger.warn(`Failed to ${label} with exit code`, exit);
                        reject(error);
                    }
                });
            });
        });
    }
    end() {
        this.sshClient?.end();
    }
}
exports.SshExecutor = SshExecutor;
//# sourceMappingURL=SshExecutor.js.map