"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ApiUserDataAdapter_1 = require("./../ApiUserDataAdapter");
jest.mock('@jfrog-pipelines/internal-clients', () => {
    return {
        PipelinesClient: jest.fn().mockImplementation(() => {
            return {
                getProjectById: jest.fn().mockImplementation((id) => {
                    return Promise.resolve({
                        id: id,
                        name: 'test-project',
                        description: 'test-project-description'
                    });
                }),
                projectIntegration: jest.fn().mockImplementation((id) => {
                    return Promise.resolve({
                        id: id,
                        name: 'Integration 1'
                    });
                }),
                getUnifiedUiAndWwwUrl: jest.fn().mockImplementation(() => {
                    return Promise.resolve({
                        unifiedUiUrl: 'https://example.com/ui',
                        wwwUrl: 'https://example.com'
                    });
                })
            };
        }),
        ServiceEnum: {
            NODE_POOL_SERVICE: 'NODE_POOL_SERVICE'
        }
    };
});
jest.mock('@jfrog-pipelines/configuration', () => {
    return {
        ConfigFactory: { config: { apiToken: 'testtoken' } }
    };
});
describe('ApiUserDataAdapter', () => {
    const adapter = new ApiUserDataAdapter_1.ApiUserDataAdapter();
    describe('getProjectById', () => {
        it('should return the project attributes for a given id', async () => {
            const id = 123;
            const projectAttributes = { id: 123, name: 'test-project', description: 'test-project-description' };
            const result = await adapter.getProjectById(id);
            expect(result).toEqual(projectAttributes);
        });
    });
    describe('getProjectIntegrationById', () => {
        it('should return the project integration attributes for a given id', async () => {
            const id = 123;
            const projectIntegrationAttributes = { id: 123, name: 'Integration 1' };
            const result = await adapter.getProjectIntegrationById(id);
            expect(result).toEqual(projectIntegrationAttributes);
        });
    });
    describe('getUnifiedUiAndWwwUrl', () => {
        it('should return the unified UI and WWW URLs', async () => {
            const unifiedUiAndWwwUrl = { unifiedUiUrl: 'https://example.com/ui', wwwUrl: 'https://example.com' };
            const result = await adapter.getUnifiedUiAndWwwUrl();
            expect(result).toEqual(unifiedUiAndWwwUrl);
        });
    });
});
//# sourceMappingURL=ApiUserDataAdapter.test.js.map