"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cache_1 = require("@jfrog-pipelines/cache");
const ApiUserDataAdapter_1 = require("../ApiUserDataAdapter");
const UserRepository_1 = require("./../UserRepository");
jest.mock('@jfrog-pipelines/configuration', () => {
    return {
        ConfigFactory: { config: { apiToken: 'testtoken' } }
    };
});
jest.mock('@jfrog-pipelines/logger', () => {
    return {
        Log: jest.fn(),
        LoggerFactory: {
            getLogger: jest.fn().mockReturnValue({
                info: jest.fn(),
                error: jest.fn(),
                debug: jest.fn(),
                trace: jest.fn(),
                warn: jest.fn()
            }),
            configure: jest.fn()
        }
    };
});
let userRepository = null;
describe('UserRepository', () => {
    beforeAll(async () => {
        await cache_1.CacheStoreFactory.registerInMemory(true);
        userRepository = new UserRepository_1.UserRepository();
    });
    describe('getProjectById', () => {
        it('should return the project attributes', async () => {
            const id = 123;
            const projectAttributes = { id: 123, name: 'Project 1' };
            const getProjectByIdSpy = jest
                .spyOn(ApiUserDataAdapter_1.ApiUserDataAdapter.prototype, 'getProjectById')
                .mockResolvedValueOnce(projectAttributes);
            expect(userRepository).not.toStrictEqual(null);
            const result = await userRepository?.getProjectById(id);
            expect(ApiUserDataAdapter_1.ApiUserDataAdapter.prototype.getProjectById).toHaveBeenCalledWith(id);
            expect(result).toStrictEqual(projectAttributes);
            expect(getProjectByIdSpy).toHaveBeenCalledWith(id);
            const secondResult = await userRepository?.getProjectById(id);
            expect(secondResult).toStrictEqual(projectAttributes);
            expect(getProjectByIdSpy).toHaveBeenCalledTimes(1);
        });
    });
    describe('getProjectIntegrationById', () => {
        it('should return the project integration attributes', async () => {
            const userRepository = new UserRepository_1.UserRepository();
            const id = 456;
            const projectIntegrationAttributes = {
                id: 456,
                integrationName: 'Integration 1'
            };
            const getProjectIntegrationByIdSpy = jest
                .spyOn(ApiUserDataAdapter_1.ApiUserDataAdapter.prototype, 'getProjectIntegrationById')
                .mockResolvedValueOnce(projectIntegrationAttributes);
            expect(userRepository).not.toStrictEqual(null);
            const result = await userRepository.getProjectIntegrationById(id);
            expect(ApiUserDataAdapter_1.ApiUserDataAdapter.prototype.getProjectIntegrationById).toHaveBeenCalledWith(id);
            expect(result).toStrictEqual(projectIntegrationAttributes);
            const secondResult = await userRepository.getProjectIntegrationById(id);
            expect(getProjectIntegrationByIdSpy).toHaveBeenCalledTimes(1);
            expect(secondResult).toStrictEqual(projectIntegrationAttributes);
        });
    });
    describe('getUnifiedUiAndWwwUrl', () => {
        it('should return the unified UI and WWW URL', async () => {
            const userRepository = new UserRepository_1.UserRepository();
            const unifiedUiAndWwwUrl = { unifiedUiUrl: 'https://example.com/ui', wwwUrl: 'https://example.com' };
            const getUnifiedUiAndWwwUrlSpy = jest
                .spyOn(ApiUserDataAdapter_1.ApiUserDataAdapter.prototype, 'getUnifiedUiAndWwwUrl')
                .mockResolvedValueOnce(unifiedUiAndWwwUrl);
            expect(userRepository).not.toStrictEqual(null);
            const result = await userRepository.getUnifiedUiAndWwwUrl();
            expect(ApiUserDataAdapter_1.ApiUserDataAdapter.prototype.getUnifiedUiAndWwwUrl).toHaveBeenCalledTimes(1);
            expect(result).toStrictEqual(unifiedUiAndWwwUrl);
            const secondResult = await userRepository.getUnifiedUiAndWwwUrl();
            expect(getUnifiedUiAndWwwUrlSpy).toHaveBeenCalledTimes(1);
            expect(secondResult).toStrictEqual(unifiedUiAndWwwUrl);
        });
    });
});
//# sourceMappingURL=UserRepository.test.js.map