"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MachineImageController = void 0;
const http_client_1 = require("@jfrog-pipelines/http-client");
const MachineImage_1 = require("../../domain/machine-image/MachineImage");
class MachineImageController {
    async get(request, response) {
        try {
            const machineImageQueryApi = new MachineImage_1.MachineImage();
            const { machineImageId } = request.params;
            const query = request.query;
            const result = await machineImageQueryApi.getById(machineImageId, query);
            return await response.send(result);
        }
        catch (error) {
            const receivedError = error;
            return response.code(receivedError.statusCode ?? http_client_1.HttpStatus.INTERNAL_SERVER_ERROR).send({
                message: receivedError.message
            });
        }
    }
    async getAll(request, response) {
        try {
            const machineImageQueryApi = new MachineImage_1.MachineImage();
            const query = request.query;
            const result = await machineImageQueryApi.get(query);
            return await response.send(result);
        }
        catch (error) {
            const receivedError = error;
            return response.code(receivedError.statusCode ?? http_client_1.HttpStatus.INTERNAL_SERVER_ERROR).send({
                message: receivedError.message
            });
        }
    }
    async create(request, response) {
        try {
            const machineImageQueryApi = new MachineImage_1.MachineImage();
            const body = request.body;
            const result = await machineImageQueryApi.create(body);
            return await response.code(http_client_1.HttpStatus.OK).send(result);
        }
        catch (error) {
            const receivedError = error;
            return response.code(receivedError.statusCode ?? http_client_1.HttpStatus.INTERNAL_SERVER_ERROR).send({
                message: receivedError.message
            });
        }
    }
    async update(request, response) {
        try {
            const machineImageQueryApi = new MachineImage_1.MachineImage();
            const { machineImageId } = request.params;
            const body = request.body;
            const result = await machineImageQueryApi.update(machineImageId, body);
            return await response.code(http_client_1.HttpStatus.OK).send(result);
        }
        catch (error) {
            const receivedError = error;
            return response.code(receivedError.statusCode ?? http_client_1.HttpStatus.INTERNAL_SERVER_ERROR).send({
                message: receivedError.message
            });
        }
    }
    async delete(request, response) {
        try {
            const machineImageQueryApi = new MachineImage_1.MachineImage();
            const { machineImageId } = request.params;
            await machineImageQueryApi.deleteById(machineImageId);
            return await response.status(http_client_1.HttpStatus.NO_CONTENT).send({});
        }
        catch (error) {
            const receivedError = error;
            return response.code(receivedError.statusCode ?? http_client_1.HttpStatus.INTERNAL_SERVER_ERROR).send({
                message: receivedError.message
            });
        }
    }
}
exports.MachineImageController = MachineImageController;
//# sourceMappingURL=MachineImageController.js.map