"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NodeController = void 0;
const node_util_1 = require("node:util");
const logger_1 = require("@jfrog-pipelines/logger");
const http_client_1 = require("@jfrog-pipelines/http-client");
const microservice_1 = require("@jfrog-pipelines/microservice");
const StatsDomainService_1 = require("../../domain/node-stats/StatsDomainService");
const node_console_1 = require("../../domain/node-console");
const NodeDomainService_1 = require("../../domain/node/NodeDomainService");
class NodeController {
    constructor() {
        this.logger = logger_1.LoggerFactory.getLogger('nodepoolRoutesV1');
    }
    async addNodeStats(request, response) {
        try {
            const nodeStatsApi = new StatsDomainService_1.StatsDomainService();
            const { nodeId } = request.params;
            const body = request.body;
            await nodeStatsApi.create(nodeId, body);
        }
        catch (error) {
            const receivedError = error;
            this.logger.warn(`Failed posting nodeStats due to error: ${(0, node_util_1.inspect)(receivedError.ormError?.name)}: ${receivedError.message}`);
            return response.code(receivedError.statusCode ?? http_client_1.HttpStatus.NOT_FOUND).send({
                message: `${receivedError.ormError?.name ?? ''} ${receivedError.message}`
            });
        }
    }
    async getNodeStats(request, response) {
        try {
            const nodeStatsApi = new StatsDomainService_1.StatsDomainService();
            const { nodeId } = request.params;
            const query = request.query;
            return await nodeStatsApi.getAll(nodeId, query);
        }
        catch (error) {
            const receivedError = error;
            this.logger.warn(`Failed posting nodeStats due to error: ${(0, node_util_1.inspect)(receivedError.ormError?.name)}: ${receivedError.message}`);
            return response.code(receivedError.statusCode ?? http_client_1.HttpStatus.NOT_FOUND).send({
                message: `${receivedError.ormError?.name ?? ''} ${receivedError.message}`
            });
        }
    }
    async getNodeConsole(request, response) {
        try {
            const nodeStatsApi = new node_console_1.NodeConsoleService();
            const { nodeId } = request.params;
            const query = request.query;
            return await nodeStatsApi.getAll(nodeId, query);
        }
        catch (error) {
            const receivedError = error;
            this.logger.warn(`Failed posting nodeStats due to error: ${(0, node_util_1.inspect)(receivedError.ormError?.name)}: ${receivedError.message}`);
            return response.code(receivedError.statusCode ?? http_client_1.HttpStatus.NOT_FOUND).send({
                message: `${receivedError.ormError?.name ?? ''} ${receivedError.message}`
            });
        }
    }
    async addNodeConsole(request, response) {
        try {
            const nodeConsoleQueryApi = new node_console_1.NodeConsoleService();
            const { nodeId } = request.params;
            const body = request.body;
            await nodeConsoleQueryApi.create(nodeId, body.message);
        }
        catch (error) {
            const receivedError = error;
            this.logger.warn(`Failed posting nodeStats due to error: ${(0, node_util_1.inspect)(receivedError.ormError?.name)}: ${receivedError.message}`);
            return response.code(receivedError.statusCode ?? http_client_1.HttpStatus.NOT_FOUND).send({
                message: `${receivedError.ormError?.name ?? ''} ${receivedError.message}`
            });
        }
    }
    async getNodeScript(request, response) {
        try {
            const certInitializer = microservice_1.applicationContext.get(microservice_1.CERTIFICATE_INITIALIZER);
            const nodeQueryApi = new NodeDomainService_1.NodeDomainService(certInitializer);
            const { nodeId } = request.params;
            const query = request.query;
            const result = await nodeQueryApi.getNodeInitScript(nodeId, query.nodePoolIds);
            return await response
                .header('Content-disposition', `attachment; filename=${result.scriptName}`)
                .type('text/plain')
                .send(result.scriptData);
        }
        catch (error) {
            const receivedError = error;
            return response.code(receivedError.statusCode ?? http_client_1.HttpStatus.INTERNAL_SERVER_ERROR).send({
                message: `${receivedError.name ?? ''} ${receivedError.message}`
            });
        }
    }
}
exports.NodeController = NodeController;
//# sourceMappingURL=NodeController.js.map