"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NodeStatsCleanupHandler = void 0;
const configuration_1 = require("@jfrog-pipelines/configuration");
const StatsDomainService_1 = require("../../domain/node-stats/StatsDomainService");
const CUT_OFF_TIME_3_DAYS_IN_MS = 259200000;
class NodeStatsCleanupHandler {
    constructor(payload) {
        this.nodeStatsService = new StatsDomainService_1.StatsDomainService();
        this.properties = configuration_1.ConfigFactory.config;
    }
    async handle() {
        if (!this.isNodesAllowed()) {
            return;
        }
        const reportedBeforeTime = this.getReportedStatsThreeDaysBefore();
        await this.nodeStatsService.deleteNodeStats(reportedBeforeTime);
    }
    isNodesAllowed() {
        if (this.properties.allowDynamicNodes || this.properties.allowCustomNodes) {
            return true;
        }
        return false;
    }
    getReportedStatsThreeDaysBefore() {
        return new Date(Date.now() - CUT_OFF_TIME_3_DAYS_IN_MS).toISOString();
    }
}
exports.NodeStatsCleanupHandler = NodeStatsCleanupHandler;
//# sourceMappingURL=NodeStatsCleanupHandler.js.map