"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const FeatureFlag_1 = require("../FeatureFlag");
const SystemConfigDao_1 = require("../../../driven/acl/systemService/SystemConfigDao");
jest.mock('@jfrog-pipelines/logger', () => {
    const actualTracker = jest.requireActual('@jfrog-pipelines/logger');
    return {
        ...actualTracker,
        LoggerFactory: {
            getLogger: jest.fn().mockReturnValue({
                info: jest.fn(),
                error: jest.fn(),
                debug: jest.fn(),
                trace: jest.fn(),
                warn: jest.fn()
            }),
            configure: jest.fn()
        }
    };
});
describe('FeatureFlags #isHotNodePoolEnabled', () => {
    it('should return false in case of flag not available', async () => {
        const daoMock = jest
            .spyOn(SystemConfigDao_1.SystemConfigDao.prototype, 'findByConfigName')
            .mockResolvedValueOnce({});
        const flags = new FeatureFlag_1.FeatureFlag();
        const flagStatus = await flags.isHotNodePoolEnabled();
        expect(flagStatus).toBe(false);
        daoMock.mockClear();
    });
    it('should return true in case of flag is available', async () => {
        const expectedDaoValue = {
            configName: 'experimentalProperties',
            configValue: { hotNodePoolsEnabled: true }
        };
        const daoMock = jest.spyOn(SystemConfigDao_1.SystemConfigDao.prototype, 'findByConfigName').mockResolvedValue(expectedDaoValue);
        const flags = new FeatureFlag_1.FeatureFlag();
        const flagStatus = await flags.isHotNodePoolEnabled();
        expect(flagStatus).toBe(true);
        daoMock.mockClear();
    });
});
//# sourceMappingURL=FeatureFlag.test.js.map